"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.identify = identify;

var _parser = require("./parser");

var allowedDialects = ['mssql', 'sqlite', 'mysql', 'psql', 'generic'];
/**
 * Identifier
 */

function identify(query) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var isStrict = typeof options.strict === 'undefined' ? true : options.strict;
  var dialect = typeof options.dialect === 'undefined' ? 'generic' : options.dialect;

  if (!allowedDialects.includes(dialect)) {
    throw new Error("Unknown dialect. Allowed values: ".concat(allowedDialects.join(',')));
  }

  var result = (0, _parser.parse)(query, isStrict, dialect);
  return result.body.map(function (statement) {
    return {
      start: statement.start,
      end: statement.end,
      text: query.substring(statement.start, statement.end + 1),
      type: statement.type,
      executionType: statement.executionType
    };
  });
}